All of lore.kernel.org
 help / color / mirror / Atom feed
From: Yoshihiro Shimoda <yoshihiro.shimoda.uh@renesas.com>
To: ulf.hansson@linaro.org, wsa+renesas@sang-engineering.com
Cc: linux-mmc@vger.kernel.org, linux-renesas-soc@vger.kernel.org,
	Yoshihiro Shimoda <yoshihiro.shimoda.uh@renesas.com>
Subject: [PATCH 2/3] mmc: tmio: No memory size limitation if runs on IOMMU
Date: Fri, 26 Apr 2019 14:18:49 +0900	[thread overview]
Message-ID: <1556255930-18188-3-git-send-email-yoshihiro.shimoda.uh@renesas.com> (raw)
In-Reply-To: <1556255930-18188-1-git-send-email-yoshihiro.shimoda.uh@renesas.com>

This patch adds a condition to avoid memory size limitaion of
swiotlb if the driver runs on IOMMU.

Tested-by: Takeshi Saito <takeshi.saito.xv@renesas.com>
Signed-off-by: Yoshihiro Shimoda <yoshihiro.shimoda.uh@renesas.com>
---
 drivers/mmc/host/tmio_mmc_core.c | 5 +++--
 1 file changed, 3 insertions(+), 2 deletions(-)

diff --git a/drivers/mmc/host/tmio_mmc_core.c b/drivers/mmc/host/tmio_mmc_core.c
index 6019628..0474337 100644
--- a/drivers/mmc/host/tmio_mmc_core.c
+++ b/drivers/mmc/host/tmio_mmc_core.c
@@ -1203,9 +1203,10 @@ int tmio_mmc_host_probe(struct tmio_mmc_host *_host)
 	 * Since swiotlb has memory size limitation, this will calculate
 	 * the maximum size locally (because we don't have any APIs for it now)
 	 * and check the current max_req_size. And then, this will update
 	 * the max_req_size if needed as a workaround.
 	 */
-	if (swiotlb_max_segment()) {
+	if (swiotlb_max_segment() && !pdev->dev.iommu_group) {
 		unsigned int max_size = (1 << IO_TLB_SHIFT) * IO_TLB_SEGSIZE;
 
 		if (mmc->max_req_size > max_size)
@@ -1203,9 +1203,10 @@ int tmio_mmc_host_probe(struct tmio_mmc_host *_host)
 	 * the maximum size locally (because we don't have any APIs for it now)
 	 * and check the current max_req_size. And then, this will update
-	 * the max_req_size if needed as a workaround.
+	 * the max_req_size if needed as a workaround. However, if the driver
+	 * runs on IOMMU, this workaround doesn't need.
 	 */
-- 
2.7.4


  parent reply	other threads:[~2019-04-26  5:23 UTC|newest]

Thread overview: 18+ messages / expand[flat|nested]  mbox.gz  Atom feed  top
2019-04-26  5:18 [PATCH 0/3] mmc: renesas_sdhi_internal_dmac: improve performance by using IOMMU Yoshihiro Shimoda
2019-04-26  5:18 ` [PATCH 1/3] mmc: tmio: add init_card ops Yoshihiro Shimoda
2019-04-26  9:15   ` Wolfram Sang
2019-04-26  9:45   ` Simon Horman
2019-04-26  9:56     ` Wolfram Sang
2019-04-26 10:17       ` Simon Horman
2019-04-26  5:18 ` Yoshihiro Shimoda [this message]
2019-04-26  8:09   ` [PATCH 2/3] mmc: tmio: No memory size limitation if runs on IOMMU Sergei Shtylyov
2019-04-26  9:17     ` Wolfram Sang
2019-05-07  7:13       ` Yoshihiro Shimoda
2019-04-26  9:45   ` Simon Horman
2019-04-26  5:18 ` [PATCH 3/3] mmc: renesas_sdhi_internal_dmac: use multiple segments if possible Yoshihiro Shimoda
2019-04-26  9:37   ` Wolfram Sang
2019-05-07  7:27     ` Yoshihiro Shimoda
2019-04-26  9:45   ` Simon Horman
2019-04-26  9:46 ` [PATCH 0/3] mmc: renesas_sdhi_internal_dmac: improve performance by using IOMMU Wolfram Sang
2019-05-07  8:58   ` Yoshihiro Shimoda
2019-05-08  4:28     ` Yoshihiro Shimoda

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Save the following mbox file, import it into your mail client,
  and reply-to-all from there: mbox

  Avoid top-posting and favor interleaved quoting:
  https://en.wikipedia.org/wiki/Posting_style#Interleaved_style

* Reply using the --to, --cc, and --in-reply-to
  switches of git-send-email(1):

  git send-email \
    --in-reply-to=1556255930-18188-3-git-send-email-yoshihiro.shimoda.uh@renesas.com \
    --to=yoshihiro.shimoda.uh@renesas.com \
    --cc=linux-mmc@vger.kernel.org \
    --cc=linux-renesas-soc@vger.kernel.org \
    --cc=ulf.hansson@linaro.org \
    --cc=wsa+renesas@sang-engineering.com \
    /path/to/YOUR_REPLY

  https://kernel.org/pub/software/scm/git/docs/git-send-email.html

* If your mail client supports setting the In-Reply-To header
  via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line before the message body.
This is an external index of several public inboxes,
see mirroring instructions on how to clone and mirror
all data and code used by this external index.